@@ -198,6 +198,15 @@ class Client:
         
         bucket, bucket_name = url.split('/')
         task_id = 'tmp_file_{}_{}'.format(bucket, bucket_name)
+
+        cached_resp = self.redis.get(task_id)
+
+        if cached_resp is not None and len(cached_resp) > 0:
+            resp = json.loads(cached_resp)
+            if resp['ret']:
+                tmp_url = resp['url']
+                return self.get_from_cloud(path, tmp_url, force_copy, min_size)
+
         
         ret = self.mq.publish(self.get_topic, {
             'bucket': bucket,
@@ -265,6 +274,14 @@ class Client:
         
         bucket, bucket_name = url.split('/')
         task_id = 'tmp_file_{}_{}'.format(bucket, bucket_name)
+
+        cached_resp = self.redis.get(task_id)
+
+        if cached_resp is not None and len(cached_resp) > 0:
+            resp = json.loads(cached_resp)
+            if resp['ret']:
+                tmp_url = resp['url']
+                return self.get_from_cloud(path, tmp_url, force_copy, min_size)
         
         ret = await self.mq.async_publish(self.get_topic, {
             'bucket': bucket,
